# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseSweepExperimentInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'experiment_id': 'int',
        'experiment_number': 'int',
        'initialized_dt': 'datetime',
        'objective_metric_name': 'str',
        'objective_metric_value': 'float',
        'parameters': 'list[ResponseParameterInfo]'
    }

    attribute_map = {
        'experiment_id': 'experiment_id',
        'experiment_number': 'experiment_number',
        'initialized_dt': 'initialized_dt',
        'objective_metric_name': 'objective_metric_name',
        'objective_metric_value': 'objective_metric_value',
        'parameters': 'parameters'
    }

    def __init__(self, experiment_id=None, experiment_number=None, initialized_dt=None, objective_metric_name=None, objective_metric_value=None, parameters=None, local_vars_configuration=None):  # noqa: E501
        """ResponseSweepExperimentInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._experiment_id = None
        self._experiment_number = None
        self._initialized_dt = None
        self._objective_metric_name = None
        self._objective_metric_value = None
        self._parameters = None
        self.discriminator = None

        if experiment_id is not None:
            self.experiment_id = experiment_id
        if experiment_number is not None:
            self.experiment_number = experiment_number
        self.initialized_dt = initialized_dt
        if objective_metric_name is not None:
            self.objective_metric_name = objective_metric_name
        self.objective_metric_value = objective_metric_value
        if parameters is not None:
            self.parameters = parameters

    @property
    def experiment_id(self):
        """Gets the experiment_id of this ResponseSweepExperimentInfo.  # noqa: E501


        :return: The experiment_id of this ResponseSweepExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._experiment_id

    @experiment_id.setter
    def experiment_id(self, experiment_id):
        """Sets the experiment_id of this ResponseSweepExperimentInfo.


        :param experiment_id: The experiment_id of this ResponseSweepExperimentInfo.  # noqa: E501
        :type experiment_id: int
        """

        self._experiment_id = experiment_id

    @property
    def experiment_number(self):
        """Gets the experiment_number of this ResponseSweepExperimentInfo.  # noqa: E501


        :return: The experiment_number of this ResponseSweepExperimentInfo.  # noqa: E501
        :rtype: int
        """
        return self._experiment_number

    @experiment_number.setter
    def experiment_number(self, experiment_number):
        """Sets the experiment_number of this ResponseSweepExperimentInfo.


        :param experiment_number: The experiment_number of this ResponseSweepExperimentInfo.  # noqa: E501
        :type experiment_number: int
        """

        self._experiment_number = experiment_number

    @property
    def initialized_dt(self):
        """Gets the initialized_dt of this ResponseSweepExperimentInfo.  # noqa: E501


        :return: The initialized_dt of this ResponseSweepExperimentInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._initialized_dt

    @initialized_dt.setter
    def initialized_dt(self, initialized_dt):
        """Sets the initialized_dt of this ResponseSweepExperimentInfo.


        :param initialized_dt: The initialized_dt of this ResponseSweepExperimentInfo.  # noqa: E501
        :type initialized_dt: datetime
        """

        self._initialized_dt = initialized_dt

    @property
    def objective_metric_name(self):
        """Gets the objective_metric_name of this ResponseSweepExperimentInfo.  # noqa: E501


        :return: The objective_metric_name of this ResponseSweepExperimentInfo.  # noqa: E501
        :rtype: str
        """
        return self._objective_metric_name

    @objective_metric_name.setter
    def objective_metric_name(self, objective_metric_name):
        """Sets the objective_metric_name of this ResponseSweepExperimentInfo.


        :param objective_metric_name: The objective_metric_name of this ResponseSweepExperimentInfo.  # noqa: E501
        :type objective_metric_name: str
        """

        self._objective_metric_name = objective_metric_name

    @property
    def objective_metric_value(self):
        """Gets the objective_metric_value of this ResponseSweepExperimentInfo.  # noqa: E501


        :return: The objective_metric_value of this ResponseSweepExperimentInfo.  # noqa: E501
        :rtype: float
        """
        return self._objective_metric_value

    @objective_metric_value.setter
    def objective_metric_value(self, objective_metric_value):
        """Sets the objective_metric_value of this ResponseSweepExperimentInfo.


        :param objective_metric_value: The objective_metric_value of this ResponseSweepExperimentInfo.  # noqa: E501
        :type objective_metric_value: float
        """

        self._objective_metric_value = objective_metric_value

    @property
    def parameters(self):
        """Gets the parameters of this ResponseSweepExperimentInfo.  # noqa: E501


        :return: The parameters of this ResponseSweepExperimentInfo.  # noqa: E501
        :rtype: list[ResponseParameterInfo]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this ResponseSweepExperimentInfo.


        :param parameters: The parameters of this ResponseSweepExperimentInfo.  # noqa: E501
        :type parameters: list[ResponseParameterInfo]
        """

        self._parameters = parameters

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseSweepExperimentInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseSweepExperimentInfo):
            return True

        return self.to_dict() != other.to_dict()
